==> geeklog-1.7.0-jp-extended-1.1.tar.gz: geeklog-1.7.0-jp-extended-1.1/plugins/nmoxtopicown/language/japanese.php <==
<?php

// +---------------------------------------------------------------------------+
// | nmoxtopicown Geeklog Plugin 1.0                                           |
// +---------------------------------------------------------------------------+
// | japanese.php                                                              |
// |                                                                           |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2007 by nmox                                                |
// |                                                                           |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

// +---------------------------------------------------------------------------+
// | Array Format:                                                             |
// | $LANGXX[YY]:	$LANG - variable name                                      |
// |	  	XX - file id number                                                |
// |		YY - phrase id number                                              |
// +---------------------------------------------------------------------------+

$LANG_NMOXTOPICOWN = array (
'nmoxtopicown'		=> '',
'plugin'            => 'ץ饰',
'access_denied'     => 'ϵݤޤ',
'access_denied_msg' => 'Root桼ΥڡˤϥǤޤ󡣤ʤΥ桼̾IPɥ쥹ϵϿޤ',
'install_header'	=> 'ץ饰Υ󥹥ȡ/󥤥󥹥ȡ',
'installed'         => 'Υץ饰ϥȤ֥饦ѹ뤳ȤǤ褦ˤץ饰Ǥ',
'uninstalled'       => 'ߡ  ץ饰ϥ󥹥ȡ뤵Ƥޤ󡣥󥹥ȡ뤹 Υ󥹥ȡܥ򲡤Ʋ',
'install_success'	=> '󥹥ȡޤ',
'install_failed'	=> '󥹥ȡ˼Ԥޤܺ٤ϥ顼(error.log)',
'uninstall_msg'		=> ' ץ饰Ϥȥ󥤥󥹥ȡ뤵ޤ',
'install'           => '󥹥ȡ',
'uninstall'			=> '󥤥󥹥ȡ',
'ok'				=> '',
'message_caution'	=> 'ˤ뤹٤Ƥε桼˾ϤޤΤǡ餫ᤴդ',
'change_writer'		=> 'εƼԤ⤳Υ桼',
'done'				=> 'ޤ'
);
?>

==> geeklog-1.8.1-jp-extended-1.0.tar.gz: geeklog-1.8.1-jp-extended-1.0/plugins/nmoxtopicown/language/japanese.php <==
<?php

// +---------------------------------------------------------------------------+
// | nmoxtopicown Geeklog Plugin                                               |
// +---------------------------------------------------------------------------+
// | japanese.php                                                              |
// |                                                                           |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2007-2011 by nmox                                           |
// |                                                                           |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// +---------------------------------------------------------------------------+

$LANG_NMOXTOPICOWN = array(
	'nmoxtopicown'		=> '',
	'plugin'            => 'ץ饰',
	'access_denied'     => 'ϵݤޤ',
	'access_denied_msg' => 'Root桼ΥڡˤϥǤޤ󡣤ʤΥ桼̾IPɥ쥹ϵϿޤ',
	'install_header'	=> 'ץ饰Υ󥹥ȡ/󥤥󥹥ȡ',
	'installed'         => 'Υץ饰ϥȤ֥饦ѹ뤳ȤǤ褦ˤץ饰Ǥ',
	'uninstalled'       => 'ߡ  ץ饰ϥ󥹥ȡ뤵Ƥޤ󡣥󥹥ȡ뤹 Υ󥹥ȡܥ򲡤Ʋ',
	'install_success'	=> '󥹥ȡޤ',
	'install_failed'	=> '󥹥ȡ˼Ԥޤܺ٤ϥ顼(error.log)',
	'uninstall_msg'		=> 'ϥץ饰ϥ󥤥󥹥ȡ뤵ޤ',
	'install'           => '󥹥ȡ',
	'uninstall'			=> '󥤥󥹥ȡ',
	'ok'				=> 'ѹ',
	'message_caution'	=> 'ˤ뤹٤Ƥε桼˾ϤޤΤǡ餫ᤴդ',
	'change_writer'		=> 'εƼԤ⤳Υ桼줹',
	'done'				=> 'ޤ',
	'invalid_token'		=> 'ƥȡ󤬴ڤˤʤäƤޤʤΥϹβǽȤߤʤޤ',
);
